@@ -49,7 +49,7 @@ def preprocess(sentence, remove_punct, remove_stop_words, stemm, lang='en'):
         
         
 class sentence_tranformer():
-    def __init__(self, source_names, target_names, model=None, return_match_idx=False, lang='en'):
+    def __init__(self, source_names, target_names, model=None, lang='en'):
         if not source_names:
             raise Exception('Inputs are empty')
         
@@ -65,7 +65,6 @@ class sentence_tranformer():
         self.source_names = source_names
         self.target_names = [target  for target in target_names if not (pd.isnull(target))] 
         self.model = model
-        self.return_match_idx = return_match_idx
         # if no model is provided use the default model
         if model is None:
             print('initializing the model...')
@@ -81,11 +80,13 @@ class sentence_tranformer():
         
 
 
-    def match(self, topn=1):
+    def match(self, topn=1, return_match_idx=False):
         '''
         Main match function. return only the top candidate for every source string.
         '''
         self.topn = topn
+        self.return_match_idx = return_match_idx
+        
         self.top_cosine_sim()
 
         match_output = self._make_matchdf()
@@ -177,7 +178,7 @@ class sentence_tranformer():
 
 
 class word_mover_distance():
-    def __init__(self, source_names, target_names, model, return_match_idx=False):
+    def __init__(self, source_names, target_names, model):
         if not source_names:
             raise Exception('Inputs are empty')
         
@@ -193,17 +194,17 @@ class word_mover_distance():
         self.source_names = source_names
         self.target_names = target_names
         self.model = model
-        self.return_match_idx = return_match_idx
         # if no model is provided use the default model
         if model is None:
             print('initializing the model (English model)...')
             self.model = api.load('glove-wiki-gigaword-300')
 
-    def match(self, topn=1):
+    def match(self, topn=1, return_match_idx=False):
         '''
         Main match function. return only the top candidate for every source string.
         '''
         self.topn = topn
+        self.return_match_idx = return_match_idx
         
         self.top_wmd_distance()
 
